@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
+import six
 import sys
+import os
 import datetime
 
-
 __all__ = ['manage']
 
 
@@ -27,6 +27,46 @@ def manage(commands, argv=None, delim=':'):
     are passed to the method. For details, see
     :class:`Cli<iktomi.management.commands.Cli>` docs.
     '''
+
+    commands = {(k.decode('utf-8') if isinstance(k, six.binary_type) else k): v
+                for k, v in commands.items()}
+
+    # Default django autocompletion script is registered to manage.py
+    # We use the same name for this script and it seems to be ok
+    # to implement the same interface
+    def perform_auto_complete(commands):
+        from .lazy import LazyCli
+        cwords = os.environ['COMP_WORDS'].split()[1:]
+        cword = int(os.environ['COMP_CWORD'])
+
+        try:
+            curr = cwords[cword - 1]
+        except IndexError:
+            curr = ''
+
+        suggest = []
+        if len(cwords) > 1 and cwords[0] in commands.keys():
+            value = commands[cwords[0]]
+            if isinstance(value, LazyCli):
+                value = value.get_digest()
+
+            for cmd_name, _ in value.get_funcs():
+                cmd_name = cmd_name[8:]
+                suggest.append(cmd_name)
+            if curr == ":":
+                curr = ''
+        else:
+            suggest += list(commands.keys()) + [x+":" for x in commands.keys()]
+        suggest.sort()
+        output = u" ".join(filter(lambda x: x.startswith(curr), suggest))
+        sys.stdout.write(output)
+
+    auto_complete = 'IKTOMI_AUTO_COMPLETE' in os.environ or \
+                    'DJANGO_AUTO_COMPLETE' in os.environ
+    if auto_complete:
+        perform_auto_complete(commands)
+        sys.exit(0)
+
     argv = sys.argv if argv is None else argv
     if len(argv) > 1:
         cmd_name = argv[1]
@@ -40,8 +80,6 @@ def manage(commands, argv=None, delim=':'):
                     k,v = splited
                 elif len(splited) == 1:
                     k,v = splited[0], True
-                else:
-                    sys.exit('Error while parsing argument "{}"'.format(item))
                 kwargs[k] = v
             else:
                 args.append(item)
@@ -56,7 +94,7 @@ def manage(commands, argv=None, delim=':'):
             digest = commands[digest_name]
         except KeyError:
             _command_list(commands)
-            sys.exit('Command "{}" not found'.format(digest_name))
+            sys.exit('ERROR: Command "{}" not found'.format(digest_name))
         try:
             if command is None:
                 if isinstance(digest, Cli):
@@ -64,23 +102,22 @@ def manage(commands, argv=None, delim=':'):
                     sys.stdout.write(help_)
                     sys.exit('ERROR: "{}" command digest requires command name'\
                                 .format(digest_name))
-                    return
                 digest(*args, **kwargs)
             else:
                 digest(command, *args, **kwargs)
         except CommandNotFound:
             help_ = digest.description(argv[0], digest_name)
             sys.stdout.write(help_)
-            sys.exit('Command "{}:{}" not found'.format(digest_name, command))
+            sys.exit('ERROR: Command "{}:{}" not found'.format(digest_name, command))
     else:
         _command_list(commands)
         sys.exit('Please provide any command')
 
 def _command_list(commands):
-    sys.stdout.write('Commands:\n')
+    sys.stdout.write(u'Commands:\n')
     for k in commands.keys():
-        sys.stdout.write(str(k))
-        sys.stdout.write('\n')
+        sys.stdout.write(k)
+        sys.stdout.write(u'\n')
 
 
 class Cli(object):
@@ -94,24 +131,24 @@ class Cli(object):
         doc += '\n'
         return doc
 
+    def get_funcs(self):
+        return [(attr, getattr(self, attr))
+                 for attr in dir(self)
+                 if attr.startswith('command_')]
+
     def description(self, argv0='manage.py', command=None):
         '''Description outputed to console'''
         command = command or self.__class__.__name__.lower()
-        if not argv0.startswith('./') and not argv0.startswith('/'):
-            argv0 = './' + argv0
-
         import inspect
-        _help = ''
-        _help += '%s\n' % command
+        _help = u''
+        _help += u'{}\n'.format(command)
         if self.__doc__:
             _help += self._fix_docstring(self.__doc__) +'\n'
         else:
-            _help += '%s\n' % command
+            _help += u'{}\n'.format(command)
 
-        funcs = [(attr, getattr(self, attr))
-                 for attr in dir(self)
-                 if attr.startswith('command_')]
-        funcs.sort(key=lambda x: x[1].func_code.co_firstlineno)
+        funcs = self.get_funcs()
+        funcs.sort(key=lambda x: six.get_function_code(x[1]).co_firstlineno)
 
         for attr, func in funcs:
             func = getattr(self, attr)
@@ -132,10 +169,10 @@ class Cli(object):
         elif hasattr(self, 'command_'+command_name):
             try:
                 getattr(self, 'command_'+command_name)(*args, **kwargs)
-            except ConverterError, e:
-                sys.stderr.write('One of the arguments for '
-                                 'command "{}" is wrong:\n'.format(command_name))
-                sys.stderr.write(str(e))
+            except ConverterError as e:
+                sys.stderr.write(u'One of the arguments for '
+                                 u'command "{}" is wrong:\n'.format(command_name))
+                sys.exit(e)
         else:
             raise CommandNotFound()
 
