@@ -13,16 +13,20 @@ TEMPLATE_DIR = join(CURDIR, 'templates')
 
 
 class TemplateEngine(object):
+    '''
+    Jinja2 engine adapter.
+    '''
     def __init__(self, paths, cache=False, extensions=None):
         '''
-        paths - list of paths
-        extensions - list of extensions
+        :param paths: list of paths
+        :param extensions: list of extensions
         '''
         self.extensions = extensions or []
         self.env = self._make_env(paths)
 
 
     def _make_env(self, paths):
+        # XXX make an interface method
         return jinja2.Environment(
             loader=jinja2.FileSystemLoader(paths),
             autoescape=True,
@@ -30,5 +34,5 @@ class TemplateEngine(object):
         )
 
     def render(self, template_name, **kw):
-        'Interface method'
+        'Interface method called from `Template.render`'
         return self.env.get_template(template_name).render(**kw)
